@@ -43,8 +43,7 @@ int main(int argc, char *argv[])
 		limit = atoi(argv[2]);
 	}
 
-	alg = enum_from_name(hash_algorithm_short_names, argv[1]);
-	if (alg == -1)
+	if (!enum_from_name(hash_algorithm_short_names, argv[1], &alg))
 	{
 		fprintf(stderr, "unknown hash algorthm: %s\n", argv[1]);
 		return 1;
