@@ -52,12 +52,14 @@ typedef struct {
 } cert_enumerator_t;
 
 METHOD(enumerator_t, cert_enumerator_enumerate, bool,
-	cert_enumerator_t *this, certificate_t **cert)
+	cert_enumerator_t *this, va_list args)
 {
-	certificate_t *trusted;
+	certificate_t *trusted, **cert;
 	public_key_t *public;
 	chunk_t chunk;
 
+	VA_ARGS_VGET(args, cert);
+
 	DESTROY_IF(this->current);
 	while (this->inner->enumerate(this->inner, &chunk))
 	{
@@ -110,7 +112,8 @@ METHOD(credential_set_t, create_cert_enumerator, enumerator_t*,
 
 	INIT(e,
 		.public = {
-			.enumerate = (void*)_cert_enumerator_enumerate,
+			.enumerate = enumerator_enumerate_default,
+			.venumerate = _cert_enumerator_enumerate,
 			.destroy = _cert_enumerator_destroy,
 		},
 		.type = key,
