@@ -231,11 +231,6 @@ struct private_ike_sa_t {
 	 */
 	chunk_t nat_detection_dest;
 
-	/**
-	 * number pending UPDATE_SA_ADDRESS (MOBIKE)
-	 */
-	uint32_t pending_updates;
-
 	/**
 	 * NAT keep alive interval
 	 */
@@ -734,8 +729,11 @@ METHOD(ike_sa_t, set_condition, void,
 			switch (condition)
 			{
 				case COND_NAT_HERE:
-				case COND_NAT_FAKE:
 				case COND_NAT_THERE:
+					DBG1(DBG_IKE, "%s host is not behind NAT anymore",
+						 condition == COND_NAT_HERE ? "local" : "remote");
+					/* fall-through */
+				case COND_NAT_FAKE:
 					set_condition(this, COND_NAT_ANY,
 								  has_condition(this, COND_NAT_HERE) ||
 								  has_condition(this, COND_NAT_THERE) ||
@@ -1052,18 +1050,6 @@ METHOD(ike_sa_t, has_mapping_changed, bool,
 	return TRUE;
 }
 
-METHOD(ike_sa_t, set_pending_updates, void,
-	private_ike_sa_t *this, uint32_t updates)
-{
-	this->pending_updates = updates;
-}
-
-METHOD(ike_sa_t, get_pending_updates, uint32_t,
-	private_ike_sa_t *this)
-{
-	return this->pending_updates;
-}
-
 METHOD(ike_sa_t, float_ports, void,
 	   private_ike_sa_t *this)
 {
@@ -2561,6 +2547,12 @@ METHOD(ike_sa_t, roam, status_t,
 			break;
 	}
 
+	if (!this->ike_cfg)
+	{	/* this is the case for new HA SAs not yet in state IKE_PASSIVE and
+		 * without config assigned */
+		return SUCCESS;
+	}
+
 	/* ignore roam events if MOBIKE is not supported/enabled and the local
 	 * address is statically configured */
 	if (this->version == IKEV2 && !supports_extension(this, EXT_MOBIKE) &&
@@ -2964,8 +2956,6 @@ ike_sa_t * ike_sa_create(ike_sa_id_t *ike_sa_id, bool initiator,
 			.supports_extension = _supports_extension,
 			.set_condition = _set_condition,
 			.has_condition = _has_condition,
-			.set_pending_updates = _set_pending_updates,
-			.get_pending_updates = _get_pending_updates,
 			.create_peer_address_enumerator = _create_peer_address_enumerator,
 			.add_peer_address = _add_peer_address,
 			.clear_peer_addresses = _clear_peer_addresses,
