@@ -67,12 +67,12 @@ typedef struct {
 	/**
 	 * Protocol of the SA
 	 */
-	u_int8_t protocol;
+	uint8_t protocol;
 
 	/**
 	 * SPI of the SA, if any
 	 */
-	u_int32_t spi;
+	uint32_t spi;
 
 	/**
 	 * SA destination address
@@ -135,7 +135,7 @@ static job_requeue_t handle_events(private_ipsec_event_relay_t *this)
 }
 
 METHOD(ipsec_event_relay_t, expire, void,
-	private_ipsec_event_relay_t *this, u_int8_t protocol, u_int32_t spi,
+	private_ipsec_event_relay_t *this, uint8_t protocol, uint32_t spi,
 	host_t *dst, bool hard)
 {
 	ipsec_event_t *event;
