@@ -49,7 +49,7 @@ struct ipsec_sa_mgr_t {
 	 * @return				SUCCESS of operation successful
 	 */
 	status_t (*get_spi)(ipsec_sa_mgr_t *this, host_t *src, host_t *dst,
-						u_int8_t protocol, u_int32_t *spi);
+						uint8_t protocol, uint32_t *spi);
 
 	/**
 	 * Add a new SA
@@ -77,11 +77,11 @@ struct ipsec_sa_mgr_t {
 	 * @return				SUCCESS if operation completed
 	 */
 	status_t (*add_sa)(ipsec_sa_mgr_t *this, host_t *src, host_t *dst,
-					   u_int32_t spi, u_int8_t protocol, u_int32_t reqid,
-					   mark_t mark, u_int32_t tfc,	lifetime_cfg_t *lifetime,
-					   u_int16_t enc_alg, chunk_t enc_key, u_int16_t int_alg,
-					   chunk_t int_key, ipsec_mode_t mode, u_int16_t ipcomp,
-					   u_int16_t cpi, bool initiator, bool encap, bool esn,
+					   uint32_t spi, uint8_t protocol, uint32_t reqid,
+					   mark_t mark, uint32_t tfc,	lifetime_cfg_t *lifetime,
+					   uint16_t enc_alg, chunk_t enc_key, uint16_t int_alg,
+					   chunk_t int_key, ipsec_mode_t mode, uint16_t ipcomp,
+					   uint16_t cpi, bool initiator, bool encap, bool esn,
 					   bool inbound, bool update);
 
 	/**
@@ -100,7 +100,7 @@ struct ipsec_sa_mgr_t {
 	 * @return				SUCCESS if operation completed
 	 */
 	status_t (*update_sa)(ipsec_sa_mgr_t *this,
-						  u_int32_t spi, u_int8_t protocol, u_int16_t cpi,
+						  uint32_t spi, uint8_t protocol, uint16_t cpi,
 						  host_t *src, host_t *dst,
 						  host_t *new_src, host_t *new_dst,
 						  bool encap, bool new_encap, mark_t mark);
@@ -119,8 +119,8 @@ struct ipsec_sa_mgr_t {
 	 * @return				SUCCESS if operation completed
 	 */
 	status_t (*query_sa)(ipsec_sa_mgr_t *this, host_t *src, host_t *dst,
-						 u_int32_t spi, u_int8_t protocol, mark_t mark,
-						 u_int64_t *bytes, u_int64_t *packets, time_t *time);
+						 uint32_t spi, uint8_t protocol, mark_t mark,
+						 uint64_t *bytes, uint64_t *packets, time_t *time);
 
 	/**
 	 * Delete a previously added SA
@@ -134,7 +134,7 @@ struct ipsec_sa_mgr_t {
 	 * @return				SUCCESS if operation completed
 	 */
 	status_t (*del_sa)(ipsec_sa_mgr_t *this, host_t *src, host_t *dst,
-					   u_int32_t spi, u_int8_t protocol, u_int16_t cpi,
+					   uint32_t spi, uint8_t protocol, uint16_t cpi,
 					   mark_t mark);
 
 	/**
@@ -159,7 +159,7 @@ struct ipsec_sa_mgr_t {
 	 * @param dst			destination address (e.g. of an inbound packet)
 	 * @return				the matching IPsec SA, or NULL if none is found
 	 */
-	ipsec_sa_t *(*checkout_by_spi)(ipsec_sa_mgr_t *this, u_int32_t spi,
+	ipsec_sa_t *(*checkout_by_spi)(ipsec_sa_mgr_t *this, uint32_t spi,
 								   host_t *dst);
 
 	/**
@@ -177,7 +177,7 @@ struct ipsec_sa_mgr_t {
 	 * @param inbound		TRUE for an inbound SA, FALSE for an outbound SA
 	 * @return				the matching IPsec SA, or NULL if none is found
 	 */
-	ipsec_sa_t *(*checkout_by_reqid)(ipsec_sa_mgr_t *this, u_int32_t reqid,
+	ipsec_sa_t *(*checkout_by_reqid)(ipsec_sa_mgr_t *this, uint32_t reqid,
 									 bool inbound);
 
 	/**
