@@ -60,7 +60,7 @@ struct private_pt_tls_client_t {
 	/**
 	 * Current PT-TLS message identifier
 	 */
-	u_int32_t identifier;
+	uint32_t identifier;
 };
 
 /**
@@ -101,8 +101,8 @@ static bool negotiate_version(private_pt_tls_client_t *this)
 {
 	bio_writer_t *writer;
 	bio_reader_t *reader;
-	u_int32_t type, vendor, identifier, reserved;
-	u_int8_t version;
+	uint32_t type, vendor, identifier, reserved;
+	uint8_t version;
 	bool res;
 
 	DBG1(DBG_TNC, "sending offer for PT-TLS version %d", PT_TLS_VERSION);
@@ -143,8 +143,8 @@ static bool negotiate_version(private_pt_tls_client_t *this)
  */
 static status_t do_sasl(private_pt_tls_client_t *this, sasl_mechanism_t *sasl)
 {
-	u_int32_t type, vendor, identifier;
-	u_int8_t result;
+	uint32_t type, vendor, identifier;
+	uint8_t result;
 	bio_reader_t *reader;
 	bio_writer_t *writer;
 	chunk_t data;
@@ -277,8 +277,8 @@ static status_t select_and_do_sasl(private_pt_tls_client_t *this)
 {
 	bio_reader_t *reader;
 	sasl_mechanism_t *sasl = NULL;
-	u_int32_t type, vendor, identifier;
-	u_int8_t len;
+	uint32_t type, vendor, identifier;
+	uint8_t len;
 	chunk_t chunk;
 	char buf[21];
 	status_t status = NEED_MORE;
@@ -364,7 +364,7 @@ static bool assess(private_pt_tls_client_t *this, tls_t *tnccs)
 		size_t buflen = PT_TLS_MAX_MESSAGE_LEN;
 		char buf[buflen];
 		bio_reader_t *reader;
-		u_int32_t vendor, type, identifier;
+		uint32_t vendor, type, identifier;
 		chunk_t data;
 
 		switch (tnccs->build(tnccs, buf, &buflen, &msglen))
