@@ -512,7 +512,7 @@ end:
 }
 
 METHOD(private_key_t, sign, bool,
-	private_bliss_private_key_t *this, signature_scheme_t scheme,
+	private_bliss_private_key_t *this, signature_scheme_t scheme, void *params,
 	chunk_t data, chunk_t *signature)
 {
 	switch (scheme)
