@@ -63,6 +63,9 @@ METHOD(plugin_t, get_features, int,
 		PLUGIN_REGISTER(PRIVKEY, pem_private_key_load, FALSE),
 			PLUGIN_PROVIDE(PRIVKEY, KEY_BLISS),
 				PLUGIN_DEPENDS(PRIVKEY, KEY_BLISS),
+		PLUGIN_REGISTER(PRIVKEY, pem_private_key_load, FALSE),
+			PLUGIN_PROVIDE(PRIVKEY, KEY_ED25519),
+				PLUGIN_DEPENDS(PRIVKEY, KEY_ED25519),
 
 		/* public key PEM decoding */
 		PLUGIN_REGISTER(PUBKEY, pem_public_key_load, FALSE),
@@ -79,6 +82,10 @@ METHOD(plugin_t, get_features, int,
 				PLUGIN_DEPENDS(PUBKEY, KEY_DSA),
 		PLUGIN_REGISTER(PUBKEY, pem_public_key_load, FALSE),
 			PLUGIN_PROVIDE(PUBKEY, KEY_BLISS),
+				PLUGIN_DEPENDS(PUBKEY, KEY_BLISS),
+		PLUGIN_REGISTER(PUBKEY, pem_public_key_load, FALSE),
+			PLUGIN_PROVIDE(PUBKEY, KEY_ED25519),
+				PLUGIN_DEPENDS(PUBKEY, KEY_ED25519),
 
 		/* certificate PEM decoding */
 		PLUGIN_REGISTER(CERT_DECODE, pem_certificate_load, FALSE),
