@@ -213,7 +213,7 @@ static bool select_suite_and_key(private_tls_server_t *this,
 static status_t process_client_hello(private_tls_server_t *this,
 									 bio_reader_t *reader)
 {
-	u_int16_t version, extension;
+	uint16_t version, extension;
 	chunk_t random, session, ciphers, compression, ext = chunk_empty;
 	bio_reader_t *extensions;
 	tls_cipher_suite_t *suites;
@@ -304,12 +304,12 @@ static status_t process_client_hello(private_tls_server_t *this,
 	}
 	else
 	{
-		count = ciphers.len / sizeof(u_int16_t);
+		count = ciphers.len / sizeof(uint16_t);
 		suites = alloca(count * sizeof(tls_cipher_suite_t));
 		DBG2(DBG_TLS, "received %d TLS cipher suites:", count);
 		for (i = 0; i < count; i++)
 		{
-			suites[i] = untoh16(&ciphers.ptr[i * sizeof(u_int16_t)]);
+			suites[i] = untoh16(&ciphers.ptr[i * sizeof(uint16_t)]);
 			DBG2(DBG_TLS, "  %N", tls_cipher_suite_names, suites[i]);
 		}
 		if (!select_suite_and_key(this, suites, count))
@@ -831,7 +831,7 @@ static tls_named_curve_t ec_group_to_curve(private_tls_server_t *this,
 bool peer_supports_curve(private_tls_server_t *this, tls_named_curve_t curve)
 {
 	bio_reader_t *reader;
-	u_int16_t current;
+	uint16_t current;
 
 	if (!this->curves_received)
 	{	/* none received, assume yes */
