@@ -350,7 +350,7 @@ imv_t* tnc_imv_create(char *name, char *path)
 	this = tnc_imv_create_empty(name);
 
 	if (lib->settings->get_bool(lib->settings, "%s.dlopen_use_rtld_now",
-								lib->ns, FALSE))
+								FALSE, lib->ns))
 	{
 		flag = RTLD_NOW;
 	}
