@@ -17,6 +17,13 @@
 #include "tpm_tss_tss2.h"
 #include "tpm_tss_trousers.h"
 
+/**
+ * Register plugins if built statically
+ */
+#ifdef STATIC_PLUGIN_CONSTRUCTORS
+#include "plugin_constructors.c"
+#endif
+
 /**
  * Described in header.
  */
